@@ -1,25 +1,26 @@
 use crate::director::director;
-use crate::sorts::ska_sort::ska_sort;
 use crate::tuning_parameters::TuningParameters;
 use crate::utils::*;
 use crate::RadixKey;
 use arbitrary_chunks::ArbitraryChunks;
 use rayon::prelude::*;
+use crate::sorts::out_of_place_sort::out_of_place_sort;
 
 pub fn recombinating_sort<T>(tuning: &TuningParameters, bucket: &mut [T], level: usize)
 where
     T: RadixKey + Sized + Send + Copy + Sync,
 {
-    let mut tmp_bucket: Vec<T> = get_tmp_bucket::<T>(bucket.len());
-
     let threads = tuning.cpus;
     let chunk_size = (bucket.len() / threads) + 1;
+    let mut tmp_bucket = get_tmp_bucket::<T>(bucket.len());
 
     let locals: Vec<([usize; 256], [usize; 256])> = bucket
-        .par_chunks_mut(chunk_size)
-        .map(|chunk| {
+        .par_chunks(chunk_size)
+        .zip(tmp_bucket.par_chunks_mut(chunk_size))
+        .map(|(chunk, tmp_chunk) | {
             let counts = get_counts(chunk, level);
-            ska_sort(chunk, &counts, level);
+
+            out_of_place_sort(chunk, tmp_chunk, &counts, level);
 
             let sums = get_prefix_sums(&counts);
 
@@ -35,7 +36,7 @@ where
         }
     });
 
-    tmp_bucket
+    bucket
         .arbitrary_chunks_mut(global_counts.clone())
         .enumerate()
         .par_bridge()
@@ -46,7 +47,7 @@ where
             for (counts, sums) in locals.iter() {
                 let read_start = read_offset + sums[index];
                 let read_end = read_start + counts[index];
-                let read_slice = &bucket[read_start..read_end];
+                let read_slice = &tmp_bucket[read_start..read_end];
                 let write_end = write_offset + read_slice.len();
 
                 global_chunk[write_offset..write_end].copy_from_slice(&read_slice);
@@ -56,13 +57,6 @@ where
             }
         });
 
-    bucket
-        .par_chunks_mut(chunk_size)
-        .zip(tmp_bucket.par_chunks(chunk_size))
-        .for_each(|(a, b)| {
-            a.copy_from_slice(&b[..]);
-        });
-
     drop(tmp_bucket);
 
     if level == 0 {
